
From: Stephen Rothwell <sfr@canb.auug.org.au>

Last of this round of the iSeries header cleanups
	- don't have two defines for the same thing (HvMaxArchitectedLps
	  and HvMaxArchitectedVirtualLans)
	- HvCallSc.h only needs linux/types.h
	- remove unused struct definition
	- add "extern" to some more function declarations

Signed-off-by: Stephen Rothwell <sfr@canb.auug.org.au>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/ppc64/kernel/viopath.c            |    4 +--
 include/asm-ppc64/iSeries/HvCallSc.h   |   34 ++++++++++++++++-----------------
 include/asm-ppc64/iSeries/HvTypes.h    |    8 ++-----
 include/asm-ppc64/iSeries/ItVpdAreas.h |    6 -----
 4 files changed, 22 insertions(+), 30 deletions(-)

diff -puN arch/ppc64/kernel/viopath.c~ppc64-iseries-misc-header-cleanups arch/ppc64/kernel/viopath.c
--- 25/arch/ppc64/kernel/viopath.c~ppc64-iseries-misc-header-cleanups	2005-06-03 02:16:07.000000000 -0700
+++ 25-akpm/arch/ppc64/kernel/viopath.c	2005-06-03 02:16:07.000000000 -0700
@@ -485,7 +485,7 @@ int viopath_open(HvLpIndex remoteLp, int
 	unsigned long flags;
 	int tempNumAllocated;
 
-	if ((remoteLp >= HvMaxArchitectedLps) || (remoteLp == HvLpIndexInvalid))
+	if ((remoteLp >= HVMAXARCHITECTEDLPS) || (remoteLp == HvLpIndexInvalid))
 		return -EINVAL;
 
 	subtype = subtype >> VIOMAJOR_SUBTYPE_SHIFT;
@@ -556,7 +556,7 @@ int viopath_close(HvLpIndex remoteLp, in
 	int numOpen;
 	struct alloc_parms parms;
 
-	if ((remoteLp >= HvMaxArchitectedLps) || (remoteLp == HvLpIndexInvalid))
+	if ((remoteLp >= HVMAXARCHITECTEDLPS) || (remoteLp == HvLpIndexInvalid))
 		return -EINVAL;
 
 	subtype = subtype >> VIOMAJOR_SUBTYPE_SHIFT;
diff -puN include/asm-ppc64/iSeries/HvCallSc.h~ppc64-iseries-misc-header-cleanups include/asm-ppc64/iSeries/HvCallSc.h
--- 25/include/asm-ppc64/iSeries/HvCallSc.h~ppc64-iseries-misc-header-cleanups	2005-06-03 02:16:07.000000000 -0700
+++ 25-akpm/include/asm-ppc64/iSeries/HvCallSc.h	2005-06-03 02:16:07.000000000 -0700
@@ -19,7 +19,7 @@
 #ifndef _HVCALLSC_H
 #define _HVCALLSC_H
 
-#include <asm/iSeries/HvTypes.h>
+#include <linux/types.h>
 
 #define HvCallBase		0x8000000000000000ul
 #define HvCallCc		0x8001000000000000ul
@@ -30,22 +30,22 @@
 #define HvCallSm		0x8007000000000000ul
 #define HvCallXm		0x8009000000000000ul
 
-u64 HvCall0(u64);
-u64 HvCall1(u64, u64);
-u64 HvCall2(u64, u64, u64);
-u64 HvCall3(u64, u64, u64, u64);
-u64 HvCall4(u64, u64, u64, u64, u64);
-u64 HvCall5(u64, u64, u64, u64, u64, u64);
-u64 HvCall6(u64, u64, u64, u64, u64, u64, u64);
-u64 HvCall7(u64, u64, u64, u64, u64, u64, u64, u64);
+extern u64 HvCall0(u64);
+extern u64 HvCall1(u64, u64);
+extern u64 HvCall2(u64, u64, u64);
+extern u64 HvCall3(u64, u64, u64, u64);
+extern u64 HvCall4(u64, u64, u64, u64, u64);
+extern u64 HvCall5(u64, u64, u64, u64, u64, u64);
+extern u64 HvCall6(u64, u64, u64, u64, u64, u64, u64);
+extern u64 HvCall7(u64, u64, u64, u64, u64, u64, u64, u64);
 
-u64 HvCall0Ret16(u64, void *);
-u64 HvCall1Ret16(u64, void *, u64);
-u64 HvCall2Ret16(u64, void *, u64, u64);
-u64 HvCall3Ret16(u64, void *, u64, u64, u64);
-u64 HvCall4Ret16(u64, void *, u64, u64, u64, u64);
-u64 HvCall5Ret16(u64, void *, u64, u64, u64, u64, u64);
-u64 HvCall6Ret16(u64, void *, u64, u64, u64, u64, u64, u64);
-u64 HvCall7Ret16(u64, void *, u64, u64 ,u64 ,u64 ,u64 ,u64 ,u64);
+extern u64 HvCall0Ret16(u64, void *);
+extern u64 HvCall1Ret16(u64, void *, u64);
+extern u64 HvCall2Ret16(u64, void *, u64, u64);
+extern u64 HvCall3Ret16(u64, void *, u64, u64, u64);
+extern u64 HvCall4Ret16(u64, void *, u64, u64, u64, u64);
+extern u64 HvCall5Ret16(u64, void *, u64, u64, u64, u64, u64);
+extern u64 HvCall6Ret16(u64, void *, u64, u64, u64, u64, u64, u64);
+extern u64 HvCall7Ret16(u64, void *, u64, u64 ,u64 ,u64 ,u64 ,u64 ,u64);
 
 #endif /* _HVCALLSC_H */
diff -puN include/asm-ppc64/iSeries/HvTypes.h~ppc64-iseries-misc-header-cleanups include/asm-ppc64/iSeries/HvTypes.h
--- 25/include/asm-ppc64/iSeries/HvTypes.h~ppc64-iseries-misc-header-cleanups	2005-06-03 02:16:07.000000000 -0700
+++ 25-akpm/include/asm-ppc64/iSeries/HvTypes.h	2005-06-03 02:16:07.000000000 -0700
@@ -40,14 +40,14 @@ typedef u64	HvIoToken;
 typedef u8	HvLpName[8];
 typedef u32	HvIoId;
 typedef u64	HvRealMemoryIndex;
-typedef u32	HvLpIndexMap;	/* Must hold HvMaxArchitectedLps bits!!! */
+typedef u32	HvLpIndexMap;	/* Must hold HVMAXARCHITECTEDLPS bits!!! */
 typedef u16	HvLpVrmIndex;
 typedef u32	HvXmGenerationId;
 typedef u8	HvLpBusPool;
 typedef u8	HvLpSharedPoolIndex;
 typedef u16	HvLpSharedProcUnitsX100;
 typedef u8	HvLpVirtualLanIndex;
-typedef u16	HvLpVirtualLanIndexMap;	/* Must hold HvMaxArchitectedVirtualLans bits!!! */
+typedef u16	HvLpVirtualLanIndexMap;	/* Must hold HVMAXARCHITECTEDVIRTUALLANS bits!!! */
 typedef u16	HvBusNumber;	/* Hypervisor Bus Number */
 typedef u8	HvSubBusNumber;	/* Hypervisor SubBus Number */
 typedef u8	HvAgentId;	/* Hypervisor DevFn */
@@ -66,15 +66,13 @@ typedef u8	HvAgentId;	/* Hypervisor DevF
 #define HVPAGESPERMEG			256
 #define HVPAGESPERCHUNK			64
 
-#define HvMaxArchitectedLps		((HvLpIndex)HVMAXARCHITECTEDLPS)
-#define HvMaxArchitectedVirtualLans	((HvLpVirtualLanIndex)16)
 #define HvLpIndexInvalid		((HvLpIndex)0xff)
 
 /*
  * Enums for the sub-components under PLIC
  * Used in HvCall  and HvPrimaryCall
  */
-enum   HvCallCompIds {
+enum {
 	HvCallCompId = 0,
 	HvCallCpuCtlsCompId = 1,
 	HvCallCfgCompId = 2,
diff -puN include/asm-ppc64/iSeries/ItVpdAreas.h~ppc64-iseries-misc-header-cleanups include/asm-ppc64/iSeries/ItVpdAreas.h
--- 25/include/asm-ppc64/iSeries/ItVpdAreas.h~ppc64-iseries-misc-header-cleanups	2005-06-03 02:16:07.000000000 -0700
+++ 25-akpm/include/asm-ppc64/iSeries/ItVpdAreas.h	2005-06-03 02:16:07.000000000 -0700
@@ -61,12 +61,6 @@
 #define ItVpdAreasMaxSlotLabels			192
 
 
-struct SlicVpdAdrs {
-	u32	pad1;
-	void	*vpdAddr;
-};
-
-
 struct ItVpdAreas {
 	u32	xSlicDesc;		// Descriptor			000-003
 	u16	xSlicSize;		// Size of this control block	004-005
_
